local _
local L
local prefix = "NomiTab"
local debug
local guild
local playerName
local date
local nomiTab = 1

local function output(msg, omit)
	print((not omit and prefix .. " - " or "") .. msg)
end

local function dbg(msg)
	if debug then
		output(msg, 1)
	end
end

local function printHelp(type)
	if type and L[type] then
		output(L[type])
	else
		local help = {
				"'graph': show graph of throughput",
				"'compare': compare gains since <x> days ago (if no data present, use closest data)",
				"'help': display this text"
				}
		output("Available commands:")

		for i = 1, #help do
			output(help[i], 1)
		end
	end
end

local function getCmd(msg)
	if msg then
		local a,b,c = strfind(msg, "(%S+)")
		if a then
			return c, strsub(msg, b+2)
		else	
			return ""
		end
	end
end

local function initDate()
	guild = GetGuildInfo("player")

	if not NomiTab_Data[guild] then
		NomiTab_Data[guild] = {}
	end

	NomiTab_Data[guild][date] = {
					["\124cffffffff\124Hitem:74653:0:0:0:0:0:0:0:90:0:0\124h[Steamed Crab Surprise]\124h\124r"] = 0,
					["\124cffffffff\124Hitem:74646:0:0:0:0:0:0:0:90:0:0\124h[Black Pepper Ribs and Shrimp]\124h\124r"] = 0,
					["\124cffffffff\124Hitem:74656:0:0:0:0:0:0:0:90:0:0\124h[Chun Tian Spring Rolls]\124h\124r"] = 0,
					["\124cffffffff\124Hitem:74648:0:0:0:0:0:0:0:90:0:0\124h[Sea Mist Rice Noodles]\124h\124r"] = 0,
					["\124cffffffff\124Hitem:74650:0:0:0:0:0:0:0:90:0:0\124h[Mogu Fish Stew]\124h\124r"] = 0
				}
end

local function updateDate()
	local old = date
	date = tonumber(_G["date"]("%y%m%d"))

	if date ~= old then
		initDate()
	end
end

local function init()
	playerName = UnitName("player")
	date = 0

	if not NomiTab_Data then
		NomiTab_Data = {}
	end

	updateDate()

	L = Loc["enUS"]
	Loc = nil

	NomiTab:UnregisterEvent("ADDON_LOADED")
end

local function compareData(dataA, dataB, last, store)
	local diff = {}
	local msg = {}
	local balance = 0

	msg[1] = "Results since " .. 
			((last == date and "earlier today") or (last == date - 1 and "yesterday") or ((last .. ""):sub(7,8) .. "/" .. (last .. ""):sub(5,6))) .. ":"

	for itemLink, count in pairs(dataB) do
		diff[itemLink] = count - dataA[itemLink]

		if diff[itemLink] ~= 0 then
			msg[#msg + 1] = itemLink .. " : " .. (count - diff[itemLink]) .. "|cff" .. ((diff[itemLink] > 0 and "00ff00+") or (diff[itemLink] < 0 and "ff0000-")) .. math.abs(diff[itemLink]) .. "|r"
		end

		balance = balance + diff[itemLink]
	end

	if msg[2] then
		output(msg[1])
		for i = 2, #msg do
			output(msg[i], 1)
		end

		if balance ~= 0 then
			output("|cffff0000The sum is not zero! Difference of |r" .. balance .. "|cffff0000.|r", 1)
		end

		if store then
			for itemLink, count in pairs(dataB) do
				dataA[itemLink] = dataA[itemLink] + diff[itemLink]
			end
		end
	end
end

local function readTab(tab)
	local data = {}
	local old = date
	updateDate()

	local texturePath, itemCount, locked, itemLink

	for slot = 1, 98 do
		texturePath, itemCount, locked = GetGuildBankItemInfo(tab, slot)
		itemLink = GetGuildBankItemLink(tab, slot)

		if itemLink then
			data[itemLink] = (data[itemLink] or 0) + itemCount
		end
	end

	local last = (date ~= old and old or date)

	compareData(NomiTab_Data[guild][last], data, last, true)
end

local function command(msg)
	local cmd, subCmd = getCmd(msg)

	if cmd == "graph" then
		local last, number = getCmd(subCmd)

		last = tonumber(last)
		number = tonumber(number)

		if last then
			if number then
				
			else
				
			end
		else
			printHelp("notlast")
		end
	elseif cmd == "compare" then
		local tar, number = getCmd(subCmd)

		tar = tonumber(tar)

		if tar then
			local oldArr

			tar = date - math.abs(tar)

			while true do
				oldArr = NomiTab_Data[guild][tar]

				if oldArr then
					break
				end

				tar = tar + 1

				if tar > 10000 then
					return
				end
			end

			oldArr = NomiTab_Data[guild][tar]
			if oldAdd then
				compareData(oldArr, NomiTab_Data[guild][date], date)
			end
		end
	else
		printHelp()
	end
end

function NomiTab_OnEvent(self, event, ...)
	if event == "ADDON_LOADED" and ... == "NomiTab" then
		init()
	elseif event == "GUILDBANKFRAME_OPENED" then
		if GetCurrentGuildBankTab() ~= nomiTab then
			SetCurrentGuildBankTab(nomiTab)
		end

		QueryGuildBankTab(nomiTab)

		readTab(nomiTab)
	elseif event == "GUILDBANKBAGSLOTS_CHANGED" then
		
	end
end

function NomiTab_OnLoad()
	local regs = {
			"ADDON_LOADED",
			"GUILDBANKFRAME_OPENED",
			"GUILDBANKBAGSLOTS_CHANGED"
		}

	for i = 1, #regs do
		NomiTab:RegisterEvent(regs[i])
	end

	SLASH_NOMITAB1 = "/nt"
	SLASH_NOMITAB2 = "/nomi"
	SLASH_NOMITAB3 = "/nomitab"
	SlashCmdList["NOMITAB"] = command
end